optmanage.manager
=================

.. automodule:: optmanage.manager

OptionManager
-------------

.. autoclass:: optmanage.manager.OptionManager
    :show-inheritance:
    :members:
    :special-members: __call__, __getitem__, __setitem__
